@@ -1,7 +1,7 @@
 """
 Congregate - GitLab instance migration utility
 
-Copyright (c) 2021 - GitLab
+Copyright (c) 2022 - GitLab
 """
 
 import os
@@ -69,6 +69,18 @@ class BaseConfig(object):
             return split(r', |,', sub(r'\[|\]|\"\"\"', '', self.config.get(section, option)))
         return default
 
+    def prop_array(self, section, option, default=None, obfuscated=False):
+        """
+            Comma separated string values
+        """
+        if self.option_exists(section, option):
+            props = [p.strip(" ")
+                     for p in self.config.get(section, option).split(",")]
+            if not obfuscated:
+                return props
+            return [deobfuscate(p) for p in props]
+        return default
+
     def prop_dict(self, section, option, default=None):
         """
             Returns configuration property JSON string as a dictionary
