@@ -62,12 +62,13 @@ def token_rotate(function):
     """
     @wraps(function)
     def f_rotate(*args, **kwargs):
-        if args[0].token_array:
-            log.info("Rotating token")
+        tokens = args[0].token_array
+        if tokens and len(tokens) > 1:
             args[0].index += 1
-            index = args[0].index % len(args[0].token_array)
-            args[0].token = args[0].token_array[index]
-        else:
+            index = args[0].index % len(tokens)
+            log.debug(f"Rotating to token index {index}")
+            args[0].token = tokens[index]
+        elif not tokens:
             log.info("No tokens provided")
         return function(*args, **kwargs)
     return f_rotate
